//@line 36 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/de/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/de/browser/firefox-l10n.js"

pref("general.useragent.locale", "de");
